//
//  Top3TableViewController.m
//  Game
//
//  Created by Santiago Pavón on 15/11/13.
//  Copyright (c) 2013 UPM. All rights reserved.
//

#import "Top3TableViewController.h"

#define GAME_URL @"http://localhost:3000/scores/top3.json"

@interface Top3TableViewController ()

@property (nonatomic,strong) NSArray * top3Scores;
@property (weak, nonatomic) IBOutlet UIBarButtonItem *refreshButton;

@end

@implementation Top3TableViewController

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    // Uncomment the following line to preserve selection between presentations.
    // self.clearsSelectionOnViewWillAppear = NO;
 
    // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
    // self.navigationItem.rightBarButtonItem = self.editButtonItem;
    
    [self getTop3:nil];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}



- (IBAction)getTop3:(UIBarButtonItem *)sender {
    
    self.title = @"Descargando ...";
    self.refreshButton.enabled = NO;
    [[UIApplication sharedApplication] setNetworkActivityIndicatorVisible:YES];
	
    NSString *escapedURL = [GAME_URL stringByAddingPercentEscapesUsingEncoding:NSUTF8StringEncoding];
    NSURL *url = [NSURL URLWithString:escapedURL];

    NSURLRequest *req = [NSURLRequest requestWithURL:url];
	
    NSHTTPURLResponse * responseHTTP = nil;
    NSError * error = nil;
    NSData * data = [NSURLConnection sendSynchronousRequest:req
                                          returningResponse:&responseHTTP
                                                      error:&error];
    if (data) {
        NSInteger statusCode = [responseHTTP statusCode];
        NSLog(@"Codigo de respuesta = %d", statusCode);
        if ( statusCode != 200 ) {
            self.title = @"Error descargando Top 3";
        } else { //--- Parsear el JSON ---
            [self parseTop3:data];
        }
    } else {  // No pudo realizarse la conexion o la descarga fallo.
        self.title = @"Error descargando Top 3";
        NSLog(@"Error Cargando Top 3: %@",[error localizedFailureReason]);
    }
	
    self.refreshButton.enabled = YES;
    [[UIApplication sharedApplication] setNetworkActivityIndicatorVisible:FALSE];
    
    
}


- (void)parseTop3:(NSData *)data {
    
    self.title = @"Analizando Top 3";
    
    NSArray * newTop3;
    NSError * err;
    if (data) {
        newTop3 = [NSJSONSerialization JSONObjectWithData:data
                                                  options:0
                                                    error:&err];
    }

    if (!newTop3) {
        NSLog(@"Error parsing JSON = %@",[err localizedDescription]);
        self.title = @"Desactualizado";
    } else {
        self.top3Scores = newTop3;
        [self.tableView reloadData];
        self.title = @"Top 3";
    }
    self.refreshButton.enabled = YES;
    [[UIApplication sharedApplication] setNetworkActivityIndicatorVisible:FALSE];
}


#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}



- (NSInteger) tableView:(UITableView *)tableView
  numberOfRowsInSection:(NSInteger)section
{
    return [self.top3Scores count];
}



- (UITableViewCell *)tableView:(UITableView *)tableView
         cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Score Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier
                                                            forIndexPath:indexPath];
    
    NSDictionary *dic = self.top3Scores[indexPath.row];
    
    cell.textLabel.text       = dic[@"name"];
    cell.detailTextLabel.text = [dic[@"total"] description];

    return cell;
}







/*
// Override to support conditional editing of the table view.
- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the specified item to be editable.
    return YES;
}
*/

/*
// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        // Delete the row from the data source
        [tableView deleteRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationFade];
    }   
    else if (editingStyle == UITableViewCellEditingStyleInsert) {
        // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
    }   
}
*/

/*
// Override to support rearranging the table view.
- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath
{
}
*/

/*
// Override to support conditional rearranging of the table view.
- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the item to be re-orderable.
    return YES;
}
*/

/*
#pragma mark - Navigation

// In a story board-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender
{
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}

 */

@end
